@@ -53,6 +53,14 @@ def get_frame_handler(frame_type: int) -> str:
     raise UnknownFrameError(f"Unknown frame type ({frame_type})")
 
 
+@dataclass
+class DataFrameDescription:
+    """Describes what data is provided by the frame."""
+
+    frame_type: FrameType
+    provides: str
+
+
 @dataclass
 class FrameDataClass:
     """Data class mixin for the frame."""
