@@ -1,11 +1,12 @@
 """Contains alarms structure decoder."""
 from __future__ import annotations
 
-from typing import Optional, Tuple
+from typing import Final, Optional, Tuple
 
-from pyplumio.const import ATTR_PENDING_ALERTS
 from pyplumio.helpers.typing import DeviceDataType
-from pyplumio.structures import StructureDecoder, make_device_data
+from pyplumio.structures import StructureDecoder, ensure_device_data
+
+ATTR_PENDING_ALERTS: Final = "pending_alerts"
 
 
 class PendingAlertsStructure(StructureDecoder):
@@ -16,7 +17,6 @@ class PendingAlertsStructure(StructureDecoder):
     ) -> Tuple[DeviceDataType, int]:
         """Decode bytes and return message data and offset."""
         alerts_number = message[offset]
-        pending_alerts = [message[offset + i] for i in range(alerts_number)]
-        return make_device_data(data, {ATTR_PENDING_ALERTS: pending_alerts}), (
+        return ensure_device_data(data, {ATTR_PENDING_ALERTS: alerts_number}), (
             offset + alerts_number + 1
         )
